==> nonebot_plugin_auto_sendlike-0.0.1.tar.gz: nonebot_plugin_auto_sendlike-0.0.1/README.md <==

<div align="center">
  <a href="https://v2.nonebot.dev/store"><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/nbp_logo.png" width="180" height="180" alt="NoneBotPluginLogo"></a>
  <br>
  <p><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/NoneBotPlugin.svg" width="240" alt="NoneBotPluginText"></p>
</div>

<div align="center">

# nonebot-plugin-auto-sendlike

_✨适用于 nonebot2 的点赞、订阅赞功能，每天 12 点定时点赞👍！轻量、高效、便捷的小插件！ ✨_

<a href="./LICENSE">
    <img src="https://img.shields.io/github/license/owner/nonebot-plugin-template.svg" alt="license">
</a>
<a href="https://pypi.python.org/pypi/nonebot-plugin-template">
    <img src="https://img.shields.io/pypi/v/nonebot-plugin-template.svg" alt="pypi">
</a>
<img src="https://img.shields.io/badge/python-3.9+-blue.svg" alt="python">

</div>

## 💿 安装

<details open>
<summary>使用 nb-cli 安装</summary>
在 nonebot2 项目的根目录下打开命令行, 输入以下指令即可安装

    nb plugin install nonebot-plugin-auto-sendlike

</details>

<details>
<summary>使用包管理器安装</summary>
在 nonebot2 项目的插件目录下, 打开命令行, 根据你使用的包管理器, 输入相应的安装命令

<details>
<summary>pip</summary>

    pip install nonebot-plugin-auto-sendlike
</details>
<details>
<summary>pdm</summary>

    pdm add nonebot-plugin-auto-sendlike
</details>
<details>
<summary>poetry</summary>

    poetry add nonebot-plugin-auto-sendlike
</details>
<details>
<summary>conda</summary>

    conda install nonebot-plugin-auto-sendlike
</details>

打开 nonebot2 项目根目录下的 `pyproject.toml` 文件, 在 `[tool.nonebot]` 部分追加写入

    plugins = ["nonebot-plugin-auto-sendlike"]

</details>

## ⚙️ 配置

@todo

## 🎉 使用

### 指令表
| 指令  | 权限 | 需要@ | 范围 | 说明 |
|:---:|:----:|:----:|:----:|:----:|
| 赞我  | 群员 | 否 | 群聊 | 指令说明 |
| 订阅赞 | 群员 | 否 | 群聊 | 指令说明 |

### 效果图

@todo

==> nonebot_plugin_auto_sendlike-0.0.2.tar.gz: nonebot_plugin_auto_sendlike-0.0.2/README.md <==

<div align="center">
  <a href="https://v2.nonebot.dev/store"><img src="https://s2.loli.net/2024/11/01/Ep7h9ntFSbrlVGH.png" width="180" height="180" alt="NoneBotPluginLogo"></a>
  <br>
  <p><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/NoneBotPlugin.svg" width="240" alt="NoneBotPluginText"></p>
</div>

<div align="center">

# nonebot-plugin-auto-sendlike

_✨适用于 nonebot2 的点赞、订阅赞功能，每天 12 点定时点赞👍！✨_

_✨一个轻量、高效、便捷的小插件！ （Logo 源自我的朋友🐶哥小助手的延伸）✨_

<a href="./LICENSE">
    <img src="https://img.shields.io/github/license/owner/nonebot-plugin-auto-sendlike.svg" alt="license">
</a>
<a href="https://pypi.python.org/pypi/nonebot-plugin-auto-sendlike">
    <img src="https://img.shields.io/pypi/v/nonebot-plugin-auto-sendlike.svg" alt="pypi">
</a>
<img src="https://img.shields.io/badge/python-3.9+-blue.svg" alt="python">

</div>

## 💿 安装

<details open>
<summary>使用 nb-cli 安装</summary>
在 nonebot2 项目的根目录下打开命令行, 输入以下指令即可安装

    nb plugin install nonebot-plugin-auto-sendlike

</details>

<details>
<summary>使用包管理器安装</summary>
在 nonebot2 项目的插件目录下, 打开命令行, 根据你使用的包管理器, 输入相应的安装命令

<details>
<summary>pip</summary>

    pip install nonebot-plugin-auto-sendlike
</details>
<details>
<summary>pdm</summary>

    pdm add nonebot-plugin-auto-sendlike
</details>
<details>
<summary>poetry</summary>

    poetry add nonebot-plugin-auto-sendlike
</details>
<details>
<summary>conda</summary>

    conda install nonebot-plugin-auto-sendlike
</details>

打开 nonebot2 项目根目录下的 `pyproject.toml` 文件, 在 `[tool.nonebot]` 部分追加写入

    plugins = ["nonebot-plugin-auto-sendlike"]

</details>

## ⚙️ 配置

@todo

## 🎉 使用

### 指令表
| 指令  | 权限 | 需要@ | 范围 | 说明 |
|:---:|:----:|:----:|:----:|:----:|
| 赞我  | 群员 | 否 | 群聊 | 指令说明 |
| 订阅赞 | 群员 | 否 | 群聊 | 指令说明 |

### 效果图

@todo
